@@ -28,15 +28,8 @@
 #include "goasmtpauth.h"
 #include "goautils.h"
 
-/**
- * GoaImapSmtpProvider:
- *
- * The #GoaImapSmtpProvider structure contains only private data and should
- * only be accessed using the provided API.
- */
 struct _GoaImapSmtpProvider
 {
-  /*< private >*/
   GoaProvider parent_instance;
 };
 
@@ -47,14 +40,6 @@ struct _GoaImapSmtpProviderClass
   GoaProviderClass parent_class;
 };
 
-/**
- * SECTION:goaimapsmtpprovider
- * @title: GoaImapSmtpProvider
- * @short_description: A provider for IMAP and SMTP servers
- *
- * #GoaImapSmtpProvider is used to access IMAP and SMTP mail servers.
- */
-
 G_DEFINE_TYPE_WITH_CODE (GoaImapSmtpProvider, goa_imap_smtp_provider, GOA_TYPE_PROVIDER,
                          goa_provider_ensure_extension_points_registered ();
                          g_io_extension_point_implement (GOA_PROVIDER_EXTENSION_POINT_NAME,
@@ -463,7 +448,7 @@ ensure_credentials_sync (GoaProvider         *provider,
                            */
                           _("Invalid %s with username ‘%s’ (%s, %d): "),
                           "smtp-password",
-                          smtp_username,
+                          imap_username,
                           g_quark_to_string ((*error)->domain),
                           (*error)->code);
           (*error)->domain = GOA_ERROR;
