@@ -30,6 +30,7 @@
 #include "goaowncloudprovider.h"
 #include "goayahooprovider.h"
 #include "goaflickrprovider.h"
+#include "goafoursquareprovider.h"
 #include "goawindowsliveprovider.h"
 #include "goatelepathyfactory.h"
 #include "goapocketprovider.h"
@@ -781,6 +782,9 @@ static struct
 #ifdef GOA_POCKET_ENABLED
   { GOA_POCKET_NAME, goa_pocket_provider_get_type },
 #endif
+#ifdef GOA_FOURSQUARE_ENABLED
+  { GOA_FOURSQUARE_NAME, goa_foursquare_provider_get_type },
+#endif
 #ifdef GOA_EXCHANGE_ENABLED
   { GOA_EXCHANGE_NAME, goa_exchange_provider_get_type },
 #endif
@@ -1033,10 +1037,6 @@ out:
  *
  * See goa_provider_get_for_provider_type() for details on how the providers
  * are found.
- *
- * Returns: (transfer full) (element-type GoaProvider): A list
- *   of element providers that should be freed with g_list_free()
- *   after each element has been freed with g_object_unref().
  */
 void
 goa_provider_get_all (GAsyncReadyCallback callback,
@@ -1074,11 +1074,8 @@ goa_provider_get_all (GAsyncReadyCallback callback,
   for (l = extensions, i = 0; l != NULL; l = l->next, i++)
     {
       GIOExtension *extension = l->data;
-      GoaProviderFactory *factory;
-
-      factory = GOA_PROVIDER_FACTORY (g_object_new (g_io_extension_get_type (extension), NULL));
-      goa_provider_factory_get_providers (factory, get_providers_cb, data);
-      g_object_unref (factory);
+      goa_provider_factory_get_providers (g_object_new (g_io_extension_get_type (extension), NULL),
+          get_providers_cb, data);
       data->pending_calls++;
     }
 
@@ -1087,7 +1084,8 @@ goa_provider_get_all (GAsyncReadyCallback callback,
 
 /**
  * goa_provider_get_all_finish:
- * @out_providers: (out): Return location for a list of #GoaProvider instances.
+ * @out_providers: (out) (transfer full) (element-type GoaProvider):
+ * Return location for a list of #GoaProvider instances.
  * @res: A #GAsyncResult obtained from the #GAsyncReadyCallback passed to goa_provider_get_all().
  * @error: Return location for error or %NULL.
  *
@@ -1158,27 +1156,6 @@ goa_provider_get_preseed_data (GoaProvider *provider)
 
 /* ---------------------------------------------------------------------------------------------------- */
 
-/**
- * SECTION:goautil
- * @title: Utilities
- * @short_description: Various utility routines
- *
- * Various utility routines.
- */
-
-/* ---------------------------------------------------------------------------------------------------- */
-
-/**
- * goa_util_add_row_widget:
- * @left: A #GtkGrid for the left side.
- * @right: A #GtkGrid for the right side.
- * @label_text: (allow-none): The text to insert on the left side or %NULL for no label.
- * @widget: A widget to insert on the right side.
- *
- * Utility function to add @label_text and @widget to @table.
- *
- * Returns: (transfer none): The #GtkWidget that was inserted (e.g. @widget itself).
- */
 GtkWidget *
 goa_util_add_row_widget (GtkGrid      *grid,
                          gint          row,
@@ -1407,7 +1384,7 @@ goa_util_add_row_switch_from_keyfile_with_blurb (GtkGrid      *grid,
                               G_BINDING_BIDIRECTIONAL | G_BINDING_INVERT_BOOLEAN);
     }
 
-  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_box_set_homogeneous (GTK_BOX (hbox), FALSE);
 
   if (blurb != NULL)
